<?php
namespace ElementorCountDownPro\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * @since 1.1.0
 */
class CountDownPro extends Widget_Base {

  /**
   * Retrieve the widget name.
   *
   * @since 1.1.0
   *
   * @access public
   *
   * @return string Widget name.
   */
  public function get_name() {
    return 'Count_Down_Pro';
  }

  /**
   * Retrieve the widget title.
   *
   * @since 1.1.0
   *
   * @access public
   *
   * @return string Widget title.
   */
  public function get_title() {
    return esc_html__( 'CountDown Pro', 'elementor-countdownpro' );
  }

  /**
   * Retrieve the widget icon.
   *
   * @since 1.1.0
   *
   * @access public
   *
   * @return string Widget icon.
   */
  public function get_icon() {
    //return 'far fa-clock';
    return 'eicon-countdown';
  }

  /**
   * Retrieve the list of categories the widget belongs to.
   *
   * Used to determine where to display the widget in the editor.
   *
   * Note that currently Elementor supports only one category.
   * When multiple categories passed, Elementor uses the first one.
   *
   * @since 1.1.0
   *
   * @access public
   *
   * @return array Widget categories.
   */
  public function get_categories() {
    return [ 'lambert-widgets' ];
  }

  /**
   * Register the widget controls.
   *
   * Adds different input fields to allow the user to change and customize the widget settings.
   *
   * @since 1.1.0
   *
   * @access protected
   */
  protected function register_controls() {
    //general controls (ex content)
    $this->start_controls_section(
      'general_content',
      [
        'label' => esc_html__( 'General', 'elementor-countdownpro' ),
      ]
    );

    $this->add_control(
			'beginDate', [
				'label' => __( 'Begin Date', 'elementor-countdownpro' ),
				'type' => \Elementor\Controls_Manager::DATE_TIME,
        'picker_options' => array(
            'dateFormat' => 'Y,m,d,H,i',
            'time_24hr' => true,
            'enableTime' => true,
        ),
        'label_block' => true,
        'default' => '',
        'description' => esc_html__( 'click the box to select the countdown begin date', 'elementor-countdownpro' ),
			]
		);
    $this->add_control(
			'launchingDate', [
				'label' => __( 'End Date', 'elementor-countdownpro' ),
				'type' => \Elementor\Controls_Manager::DATE_TIME,
        'picker_options' => array(
            'dateFormat' => 'Y,m,d,H,i',
            'time_24hr' => true,
            'enableTime' => true,
        ),
        'label_block' => true,
        'default' => '',
        'description' => esc_html__( 'click the box to select the countdown end date', 'elementor-countdownpro' ),
			]
		);
    $this->add_control(
			'servertime',
			[
				'label' => esc_html__( 'Use Server Time', 'elementor-countdownpro' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'elementor-countdownpro' ),
				'label_off' => esc_html__( 'No', 'elementor-countdownpro' ),
				'return_value' => 'true',
				'default' => 'true',
			]
		);
    $this->add_control(
			'responsive',
			[
				'label' => esc_html__( 'Responsive', 'elementor-countdownpro' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'elementor-countdownpro' ),
				'label_off' => esc_html__( 'No', 'elementor-countdownpro' ),
				'return_value' => 'true',
				'default' => 'true',
			]
		);
    $this->add_control(
      'pluginFontFamily',
      [
        'label' => esc_html__( 'Plugin Font Family', 'elementor-countdownpro' ),
        'type' => Controls_Manager::TEXT,
        'label_block' => true,
        'default' => 'PT Serif, serif',
        'description' => esc_html__( 'add the plugin family definition', 'elementor-countdownpro' ),
      ]
    );
    $this->add_control(
      'pluginFontFamilyGoogleLink',
      [
        'label' => esc_html__( 'Plugin Font Family Google Link', 'elementor-countdownpro' ),
        'type' => Controls_Manager::TEXT,
        'label_block' => true,
        'default' => 'https://fonts.googleapis.com/css?family=PT+Serif:400,700',
        'description' => esc_html__( 'add the plugin Google url', 'elementor-countdownpro' ),
      ]
    );
    $this->add_control(
		'logo',
		[
			'label' => esc_html__( 'Logo', 'elementor-countdownpro' ),
			'type' => \Elementor\Controls_Manager::MEDIA,
			'default' => [
				'url' => \Elementor\Utils::get_placeholder_image_src(),
			]
		]
	  );
    $this->add_control(
      'logoLink',
      [
        'label' => esc_html__( 'Logo Link', 'elementor-countdownpro' ),
        'type' => Controls_Manager::TEXT,
        'label_block' => true,
        'default' => '',
      ]
    );
    $this->add_control(
			'logoTarget',
			[
				'label' => __( 'Logo Target', 'elementor-countdownpro' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => '_self',
				'options' => [
					'_blank'  => __( 'New Window', 'elementor-countdownpro' ),
					'_self' => __( 'The Same Window', 'elementor-countdownpro' ),
				],
			]
		);
    $this->add_control(
      'circleRadius',
      [
        'label' => esc_html__( 'Circle Radius', 'elementor-countdownpro' ),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 0,
        'max' => 1000,
        'step' => 10,
        'default' => 85,
      ]
    );
    $this->add_control(
      'circleLineWidth',
      [
        'label' => esc_html__( 'Circle Line Width', 'elementor-countdownpro' ),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 0,
        'max' => 1000,
        'step' => 1,
        'default' => 20,
      ]
    );
    $this->add_control(
      'behindCircleLineWidthExpand',
      [
        'label' => esc_html__( 'Behind Circle Line Width Expand', 'elementor-countdownpro' ),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 0,
        'max' => 1000,
        'step' => 1,
        'default' => 6,
      ]
    );
    $this->add_control(
      'circleTopBottomPadding',
      [
        'label' => esc_html__( 'Circle Top Bottom Padding', 'elementor-countdownpro' ),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 0,
        'max' => 1000,
        'step' => 1,
        'default' => 20,
      ]
    );
    $this->add_control(
      'circleLeftRightPadding',
      [
        'label' => esc_html__( 'Circle Left Right Padding', 'elementor-countdownpro' ),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 0,
        'max' => 1000,
        'step' => 1,
        'default' => 30,
      ]
    );
    $this->add_control(
      'numberSize',
      [
        'label' => esc_html__( 'Number Size', 'elementor-countdownpro' ),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 0,
        'max' => 1000,
        'step' => 5,
        'default' => 60,
      ]
    );
    $this->add_control(
      'numberAdditionalTopPadding',
      [
        'label' => esc_html__( 'Number Additional Top Padding', 'elementor-countdownpro' ),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 0,
        'max' => 1000,
        'step' => 1,
        'default' => 2,
      ]
    );
    $this->add_control(
      'textSize',
      [
        'label' => esc_html__( 'Text Size', 'elementor-countdownpro' ),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 0,
        'max' => 1000,
        'step' => 5,
        'default' => 24,
      ]
    );
    $this->add_control(
      'textMarginTop',
      [
        'label' => esc_html__( 'Text Margin Top', 'elementor-countdownpro' ),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 0,
        'max' => 1000,
        'step' => 5,
        'default' => 18,
      ]
    );
    $this->add_control(
      'textPadding',
      [
        'label' => esc_html__( 'Text Padding', 'elementor-countdownpro' ),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 0,
        'max' => 1000,
        'step' => 5,
        'default' => 15,
      ]
    );
    $this->add_control(
      'allCirclesTopMargin',
      [
        'label' => esc_html__( 'Top Margin for All Circles', 'elementor-countdownpro' ),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 0,
        'max' => 1000,
        'step' => 1,
        'default' => 0,
      ]
    );
    $this->add_control(
      'allCirclesBottomMargin',
      [
        'label' => esc_html__( 'Bottom Margin for All Circles', 'elementor-countdownpro' ),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 0,
        'max' => 1000,
        'step' => 5,
        'default' => 80,
      ]
    );
    $this->add_control(
		'socialBgOFF',
		[
			'label' => esc_html__( 'Social Bg OFF State', 'elementor-countdownpro' ),
			'type' => \Elementor\Controls_Manager::MEDIA,
			'default' => [
				'url' => \Elementor\Utils::get_placeholder_image_src(),
			]
		]
	  );
    $this->add_control(
		'socialBgON',
		[
			'label' => esc_html__( 'Social Bg ON State', 'elementor-countdownpro' ),
			'type' => \Elementor\Controls_Manager::MEDIA,
			'default' => [
				'url' => \Elementor\Utils::get_placeholder_image_src(),
			]
		]
	  );
    $this->add_control(
		'lineSeparatorImg',
		[
			'label' => esc_html__( 'Line Separator Img', 'elementor-countdownpro' ),
			'type' => \Elementor\Controls_Manager::MEDIA,
			'default' => [
				'url' => \Elementor\Utils::get_placeholder_image_src(),
			]
		]
	  );
    $this->add_control(
			'complete',
			[
				'label' => __( 'CallBack Function', 'elementor-countdownpro' ),
				'type' => \Elementor\Controls_Manager::TEXTAREA,
				'rows' => 10,
				'default' => __( '', 'elementor-countdownpro' ),
				'placeholder' => __( 'function() { window.open("https://www.google.com","_blank") }', 'elementor-countdownpro' ),
        'description' => esc_html__( 'The function which will run when the countdown ends.', 'elementor-countdownpro' ),
			]
		);
    $this->add_control(
			'autoReset24h',
			[
				'label' => esc_html__( 'Auto Reset Every 24h', 'elementor-countdownpro' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'elementor-countdownpro' ),
				'label_off' => esc_html__( 'No', 'elementor-countdownpro' ),
				'return_value' => 'true',
				'default' => 'false',
			]
		);
    $this->add_control(
			'useTheseSettingsForAll',
			[
				'label' => esc_html__( 'Same settings for Days, Hours, Minutes, Seconds', 'elementor-countdownpro' ),
        'label_block' => true,
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'elementor-countdownpro' ),
				'label_off' => esc_html__( 'No', 'elementor-countdownpro' ),
				'return_value' => 'true',
				'default' => 'true',
        'description' => esc_html__( 'Each section (Days, Hours, Minutes, Seconds) has separate settings. If you want that all the sections have the same settings as "Days Settings" section, then activate this parameter.', 'elementor-countdownpro' ),
			]
		);



    $this->end_controls_section();




    $this->start_controls_section(
      'days_content',
      [
        'label' => esc_html__( 'Days Settings', 'elementor-countdownpro' ),
      ]
    );

    $this->add_control(
      'translateDays',
      [
        'label' => esc_html__( 'Translate Days', 'elementor-countdownpro' ),
        'type' => Controls_Manager::TEXT,
        'label_block' => true,
        'default' => 'DAYS',
      ]
    );
    $this->add_control(
      'divBackgroundDaysHexa',
      [
        'label' => esc_html__( 'Div Background Days - Hexa', 'elementor-countdownpro' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => true,
        'default' => '',
      ]
    );
    $this->add_control(
		'divBackgroundDaysImg',
		[
			'label' => esc_html__( 'Div Background Days - Img', 'elementor-countdownpro' ),
			'type' => \Elementor\Controls_Manager::MEDIA,
			'default' => [
				'url' => \Elementor\Utils::get_placeholder_image_src(),
			]
		]
	  );
    $this->add_control(
      'borderTopColorDays',
      [
        'label' => esc_html__( 'Border Top Color Days', 'elementor-countdownpro' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '',
      ]
    );
    $this->add_control(
      'borderRightColorDays',
      [
        'label' => esc_html__( 'Border Right Color Days', 'elementor-countdownpro' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '',
      ]
    );
    $this->add_control(
      'borderBottomColorDays',
      [
        'label' => esc_html__( 'Border Bottom Color Days', 'elementor-countdownpro' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '',
      ]
    );
    $this->add_control(
      'borderLeftColorDays',
      [
        'label' => esc_html__( 'Border Left Color Days', 'elementor-countdownpro' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '',
      ]
    );
    $this->add_control(
      'circleColorDays',
      [
        'label' => esc_html__( 'Circle Color Days', 'elementor-countdownpro' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => true,
        'default' => '#dd1e2f',
      ]
    );
    $this->add_control(
      'behindCircleColorDays',
      [
        'label' => esc_html__( 'Behind Circle Color Days', 'elementor-countdownpro' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => true,
        'default' => '#000000',
      ]
    );
    $this->add_control(
      'numberColorDays',
      [
        'label' => esc_html__( 'Number Color Days', 'elementor-countdownpro' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '#0D0404',
      ]
    );
    $this->add_control(
      'textColorDays',
      [
        'label' => esc_html__( 'Text Color Days', 'elementor-countdownpro' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '#6f6f6f',
      ]
    );
    $this->add_control(
      'textBackgroundDaysHexa',
      [
        'label' => esc_html__( 'Text Background Days - Hexa', 'elementor-countdownpro' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => true,
        'default' => '',
      ]
    );
    $this->add_control(
		'textBackgroundDaysImg',
		[
			'label' => esc_html__( 'Text Background Days - Img', 'elementor-countdownpro' ),
			'type' => \Elementor\Controls_Manager::MEDIA,
			'default' => [
				'url' => \Elementor\Utils::get_placeholder_image_src(),
			]
		]
	  );

    $this->end_controls_section();

    $this->start_controls_section(
      'hours_content',
      [
        'label' => esc_html__( 'Hours Settings', 'elementor-countdownpro' ),
      ]
    );

    $this->add_control(
      'translateHours',
      [
        'label' => esc_html__( 'Translate Hours', 'elementor-countdownpro' ),
        'type' => Controls_Manager::TEXT,
        'label_block' => true,
        'default' => 'HOURS',
      ]
    );
    $this->add_control(
      'divBackgroundHoursHexa',
      [
        'label' => esc_html__( 'Div Background Hours - Hexa', 'elementor-countdownpro' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => true,
        'default' => '',
      ]
    );
    $this->add_control(
		'divBackgroundHoursImg',
		[
			'label' => esc_html__( 'Div Background Hours - Img', 'elementor-countdownpro' ),
			'type' => \Elementor\Controls_Manager::MEDIA,
			'default' => [
				'url' => \Elementor\Utils::get_placeholder_image_src(),
			]
		]
	  );
    $this->add_control(
      'borderTopColorHours',
      [
        'label' => esc_html__( 'Border Top Color Hours', 'elementor-countdownpro' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '',
      ]
    );
    $this->add_control(
      'borderRightColorHours',
      [
        'label' => esc_html__( 'Border Right Color Hours', 'elementor-countdownpro' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '',
      ]
    );
    $this->add_control(
      'borderBottomColorHours',
      [
        'label' => esc_html__( 'Border Bottom Color Hours', 'elementor-countdownpro' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '',
      ]
    );
    $this->add_control(
      'borderLeftColorHours',
      [
        'label' => esc_html__( 'Border Left Color Hours', 'elementor-countdownpro' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '',
      ]
    );
    $this->add_control(
      'circleColorHours',
      [
        'label' => esc_html__( 'Circle Color Hours', 'elementor-countdownpro' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => true,
        'default' => '#ebb035',
      ]
    );
    $this->add_control(
      'behindCircleColorHours',
      [
        'label' => esc_html__( 'Behind Circle Color Hours', 'elementor-countdownpro' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => true,
        'default' => '#000000',
      ]
    );
    $this->add_control(
      'numberColorHours',
      [
        'label' => esc_html__( 'Number Color Hours', 'elementor-countdownpro' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '#0D0404',
      ]
    );
    $this->add_control(
      'textColorHours',
      [
        'label' => esc_html__( 'Text Color Hours', 'elementor-countdownpro' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '#6f6f6f',
      ]
    );
    $this->add_control(
      'textBackgroundHoursHexa',
      [
        'label' => esc_html__( 'Text Background Hours - Hexa', 'elementor-countdownpro' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => true,
        'default' => '',
      ]
    );
    $this->add_control(
		'textBackgroundHoursImg',
		[
			'label' => esc_html__( 'Text Background Hours - Img', 'elementor-countdownpro' ),
			'type' => \Elementor\Controls_Manager::MEDIA,
			'default' => [
				'url' => \Elementor\Utils::get_placeholder_image_src(),
			]
		]
	  );


    $this->end_controls_section();


    $this->start_controls_section(
      'minutes_content',
      [
        'label' => esc_html__( 'Minutes Settings', 'elementor-countdownpro' ),
      ]
    );

    $this->add_control(
          'translateMinutes',
          [
            'label' => esc_html__( 'Translate Minutes', 'elementor-countdownpro' ),
            'type' => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => 'MINUTES',
          ]
        );
        $this->add_control(
          'divBackgroundMinutesHexa',
          [
            'label' => esc_html__( 'Div Background Minutes - Hexa', 'elementor-countdownpro' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'scheme' => [
              'type' => \Elementor\Core\Schemes\Color::get_type(),
              'value' => \Elementor\Core\Schemes\Color::COLOR_1,
            ],
            'alpha' => true,
            'default' => '',
          ]
        );
        $this->add_control(
    		'divBackgroundMinutesImg',
    		[
    			'label' => esc_html__( 'Div Background Minutes - Img', 'elementor-countdownpro' ),
    			'type' => \Elementor\Controls_Manager::MEDIA,
    			'default' => [
    				'url' => \Elementor\Utils::get_placeholder_image_src(),
    			]
    		]
    	  );
        $this->add_control(
          'borderTopColorMinutes',
          [
            'label' => esc_html__( 'Border Top Color Minutes', 'elementor-countdownpro' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'scheme' => [
              'type' => \Elementor\Core\Schemes\Color::get_type(),
              'value' => \Elementor\Core\Schemes\Color::COLOR_1,
            ],
            'alpha' => false,
            'default' => '',
          ]
        );
        $this->add_control(
          'borderRightColorMinutes',
          [
            'label' => esc_html__( 'Border Right Color Minutes', 'elementor-countdownpro' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'scheme' => [
              'type' => \Elementor\Core\Schemes\Color::get_type(),
              'value' => \Elementor\Core\Schemes\Color::COLOR_1,
            ],
            'alpha' => false,
            'default' => '',
          ]
        );
        $this->add_control(
          'borderBottomColorMinutes',
          [
            'label' => esc_html__( 'Border Bottom Color Minutes', 'elementor-countdownpro' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'scheme' => [
              'type' => \Elementor\Core\Schemes\Color::get_type(),
              'value' => \Elementor\Core\Schemes\Color::COLOR_1,
            ],
            'alpha' => false,
            'default' => '',
          ]
        );
        $this->add_control(
          'borderLeftColorMinutes',
          [
            'label' => esc_html__( 'Border Left Color Minutes', 'elementor-countdownpro' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'scheme' => [
              'type' => \Elementor\Core\Schemes\Color::get_type(),
              'value' => \Elementor\Core\Schemes\Color::COLOR_1,
            ],
            'alpha' => false,
            'default' => '',
          ]
        );
        $this->add_control(
          'circleColorMinutes',
          [
            'label' => esc_html__( 'Circle Color Minutes', 'elementor-countdownpro' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'scheme' => [
              'type' => \Elementor\Core\Schemes\Color::get_type(),
              'value' => \Elementor\Core\Schemes\Color::COLOR_1,
            ],
            'alpha' => true,
            'default' => '#06a2cb',
          ]
        );
        $this->add_control(
          'behindCircleColorMinutes',
          [
            'label' => esc_html__( 'Behind Circle Color Minutes', 'elementor-countdownpro' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'scheme' => [
              'type' => \Elementor\Core\Schemes\Color::get_type(),
              'value' => \Elementor\Core\Schemes\Color::COLOR_1,
            ],
            'alpha' => true,
            'default' => '#000000',
          ]
        );
        $this->add_control(
          'numberColorMinutes',
          [
            'label' => esc_html__( 'Number Color Minutes', 'elementor-countdownpro' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'scheme' => [
              'type' => \Elementor\Core\Schemes\Color::get_type(),
              'value' => \Elementor\Core\Schemes\Color::COLOR_1,
            ],
            'alpha' => false,
            'default' => '#0D0404',
          ]
        );
        $this->add_control(
          'textColorMinutes',
          [
            'label' => esc_html__( 'Text Color Minutes', 'elementor-countdownpro' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'scheme' => [
              'type' => \Elementor\Core\Schemes\Color::get_type(),
              'value' => \Elementor\Core\Schemes\Color::COLOR_1,
            ],
            'alpha' => false,
            'default' => '#6f6f6f',
          ]
        );
        $this->add_control(
          'textBackgroundMinutesHexa',
          [
            'label' => esc_html__( 'Text Background Minutes - Hexa', 'elementor-countdownpro' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'scheme' => [
              'type' => \Elementor\Core\Schemes\Color::get_type(),
              'value' => \Elementor\Core\Schemes\Color::COLOR_1,
            ],
            'alpha' => true,
            'default' => '',
          ]
        );
        $this->add_control(
    		'textBackgroundMinutesImg',
    		[
    			'label' => esc_html__( 'Text Background Minutes - Img', 'elementor-countdownpro' ),
    			'type' => \Elementor\Controls_Manager::MEDIA,
    			'default' => [
    				'url' => \Elementor\Utils::get_placeholder_image_src(),
    			]
    		]
    	  );

    $this->end_controls_section();

    $this->start_controls_section(
      'seconds_content',
      [
        'label' => esc_html__( 'Seconds Settings', 'elementor-countdownpro' ),
      ]
    );

    $this->add_control(
          'translateSeconds',
          [
            'label' => esc_html__( 'Translate Seconds', 'elementor-countdownpro' ),
            'type' => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => 'SECONDS',
          ]
        );
        $this->add_control(
          'divBackgroundSecondsHexa',
          [
            'label' => esc_html__( 'Div Background Seconds - Hexa', 'elementor-countdownpro' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'scheme' => [
              'type' => \Elementor\Core\Schemes\Color::get_type(),
              'value' => \Elementor\Core\Schemes\Color::COLOR_1,
            ],
            'alpha' => true,
            'default' => '',
          ]
        );
        $this->add_control(
    		'divBackgroundSecondsImg',
    		[
    			'label' => esc_html__( 'Div Background Seconds - Img', 'elementor-countdownpro' ),
    			'type' => \Elementor\Controls_Manager::MEDIA,
    			'default' => [
    				'url' => \Elementor\Utils::get_placeholder_image_src(),
    			]
    		]
    	  );
        $this->add_control(
          'borderTopColorSeconds',
          [
            'label' => esc_html__( 'Border Top Color Seconds', 'elementor-countdownpro' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'scheme' => [
              'type' => \Elementor\Core\Schemes\Color::get_type(),
              'value' => \Elementor\Core\Schemes\Color::COLOR_1,
            ],
            'alpha' => false,
            'default' => '',
          ]
        );
        $this->add_control(
          'borderRightColorSeconds',
          [
            'label' => esc_html__( 'Border Right Color Seconds', 'elementor-countdownpro' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'scheme' => [
              'type' => \Elementor\Core\Schemes\Color::get_type(),
              'value' => \Elementor\Core\Schemes\Color::COLOR_1,
            ],
            'alpha' => false,
            'default' => '',
          ]
        );
        $this->add_control(
          'borderBottomColorSeconds',
          [
            'label' => esc_html__( 'Border Bottom Color Seconds', 'elementor-countdownpro' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'scheme' => [
              'type' => \Elementor\Core\Schemes\Color::get_type(),
              'value' => \Elementor\Core\Schemes\Color::COLOR_1,
            ],
            'alpha' => false,
            'default' => '',
          ]
        );
        $this->add_control(
          'borderLeftColorSeconds',
          [
            'label' => esc_html__( 'Border Left Color Seconds', 'elementor-countdownpro' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'scheme' => [
              'type' => \Elementor\Core\Schemes\Color::get_type(),
              'value' => \Elementor\Core\Schemes\Color::COLOR_1,
            ],
            'alpha' => false,
            'default' => '',
          ]
        );
        $this->add_control(
          'circleColorSeconds',
          [
            'label' => esc_html__( 'Circle Color Seconds', 'elementor-countdownpro' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'scheme' => [
              'type' => \Elementor\Core\Schemes\Color::get_type(),
              'value' => \Elementor\Core\Schemes\Color::COLOR_1,
            ],
            'alpha' => true,
            'default' => '#218559',
          ]
        );
        $this->add_control(
          'behindCircleColorSeconds',
          [
            'label' => esc_html__( 'Behind Circle Color Seconds', 'elementor-countdownpro' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'scheme' => [
              'type' => \Elementor\Core\Schemes\Color::get_type(),
              'value' => \Elementor\Core\Schemes\Color::COLOR_1,
            ],
            'alpha' => true,
            'default' => '#000000',
          ]
        );
        $this->add_control(
          'numberColorSeconds',
          [
            'label' => esc_html__( 'Number Color Seconds', 'elementor-countdownpro' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'scheme' => [
              'type' => \Elementor\Core\Schemes\Color::get_type(),
              'value' => \Elementor\Core\Schemes\Color::COLOR_1,
            ],
            'alpha' => false,
            'default' => '#0D0404',
          ]
        );
        $this->add_control(
          'textColorSeconds',
          [
            'label' => esc_html__( 'Text Color Seconds', 'elementor-countdownpro' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'scheme' => [
              'type' => \Elementor\Core\Schemes\Color::get_type(),
              'value' => \Elementor\Core\Schemes\Color::COLOR_1,
            ],
            'alpha' => false,
            'default' => '#6f6f6f',
          ]
        );
        $this->add_control(
          'textBackgroundSecondsHexa',
          [
            'label' => esc_html__( 'Text Background Seconds - Hexa', 'elementor-countdownpro' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'scheme' => [
              'type' => \Elementor\Core\Schemes\Color::get_type(),
              'value' => \Elementor\Core\Schemes\Color::COLOR_1,
            ],
            'alpha' => true,
            'default' => '',
          ]
        );
        $this->add_control(
    		'textBackgroundSecondsImg',
    		[
    			'label' => esc_html__( 'Text Background Seconds - Img', 'elementor-countdownpro' ),
    			'type' => \Elementor\Controls_Manager::MEDIA,
    			'default' => [
    				'url' => \Elementor\Utils::get_placeholder_image_src(),
    			]
    		]
    	  );

    $this->end_controls_section();


    $this->start_controls_section(
      'h_tags_content',
      [
        'label' => esc_html__( 'H tags Settings', 'elementor-countdownpro' ),
      ]
    );

    $this->add_control(
      'h2Text',
      [
        'label' => esc_html__( 'H2 Content', 'elementor-countdownpro' ),
        'type' => Controls_Manager::TEXT,
        'label_block' => true,
        'default' => '',
      ]
    );
    $this->add_control(
      'h2Size',
      [
        'label' => esc_html__( 'H2 Size', 'elementor-countdownpro' ),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 0,
        'max' => 1000,
        'step' => 1,
        'default' => 36,
      ]
    );
    $this->add_control(
      'h2Color',
      [
        'label' => esc_html__( 'H2 Color', 'elementor-countdownpro' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '#6f6f6f',
      ]
    );
    $this->add_control(
			'h2Weight',
			[
				'label' => __( 'H2 Weight', 'elementor-countdownpro' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'bold',
				'options' => [
          'bold' => __( 'Bold', 'elementor-countdownpro' ),
					'normal'  => __( 'Normal', 'elementor-countdownpro' ),
				],
			]
		);
    $this->add_control(
      'h2TopMargin',
      [
        'label' => esc_html__( 'H2 Top Margin', 'elementor-countdownpro' ),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 0,
        'max' => 1000,
        'step' => 1,
        'default' => 60,
      ]
    );
    $this->add_control(
      'h3Text',
      [
        'label' => esc_html__( 'H3 Content', 'elementor-countdownpro' ),
        'type' => Controls_Manager::TEXT,
        'label_block' => true,
        'default' => '',
      ]
    );
    $this->add_control(
      'h3Size',
      [
        'label' => esc_html__( 'H3 Size', 'elementor-countdownpro' ),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 0,
        'max' => 1000,
        'step' => 1,
        'default' => 24,
      ]
    );
    $this->add_control(
      'h3Color',
      [
        'label' => esc_html__( 'H3 Color', 'elementor-countdownpro' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '#6f6f6f',
      ]
    );
    $this->add_control(
			'h3Weight',
			[
				'label' => __( 'H3 Weight', 'elementor-countdownpro' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => 'normal',
				'options' => [
          'normal'  => __( 'Normal', 'elementor-countdownpro' ),
          'bold' => __( 'Bold', 'elementor-countdownpro' ),
				],
			]
		);
    $this->add_control(
      'h3TopMargin',
      [
        'label' => esc_html__( 'H3 Top Margin', 'elementor-countdownpro' ),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 0,
        'max' => 1000,
        'step' => 1,
        'default' => 0,
      ]
    );
    $this->add_control(
          'h4Text',
          [
            'label' => esc_html__( 'H4 Content', 'elementor-countdownpro' ),
            'type' => Controls_Manager::TEXT,
            'label_block' => true,
            'default' => '',
            'description' => esc_html__( 'it will appear only if you have defined at least one social channel', 'elementor-countdownpro' ),
          ]
        );
        $this->add_control(
          'h4Size',
          [
            'label' => esc_html__( 'H4 Size', 'elementor-countdownpro' ),
            'type' => \Elementor\Controls_Manager::NUMBER,
            'min' => 0,
            'max' => 1000,
            'step' => 1,
            'default' => 14,
          ]
        );
        $this->add_control(
          'h4Color',
          [
            'label' => esc_html__( 'H4 Color', 'elementor-countdownpro' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'scheme' => [
              'type' => \Elementor\Core\Schemes\Color::get_type(),
              'value' => \Elementor\Core\Schemes\Color::COLOR_1,
            ],
            'alpha' => false,
            'default' => '#6f6f6f',
          ]
        );
        $this->add_control(
    			'h4Weight',
    			[
    				'label' => __( 'H4 Weight', 'elementor-countdownpro' ),
    				'type' => \Elementor\Controls_Manager::SELECT,
    				'default' => 'normal',
    				'options' => [
              'normal'  => __( 'Normal', 'elementor-countdownpro' ),
              'bold' => __( 'Bold', 'elementor-countdownpro' ),
    				],
    			]
    		);
        $this->add_control(
          'h4TopMargin',
          [
            'label' => esc_html__( 'H4 Top Margin', 'elementor-countdownpro' ),
            'type' => \Elementor\Controls_Manager::NUMBER,
            'min' => 0,
            'max' => 1000,
            'step' => 1,
            'default' => 15,
          ]
        );

    $this->end_controls_section();



    /*playlist controls*/
    $this->start_controls_section(
      'playlist_content',
      [
        'label' => esc_html__( 'Social Channels', 'elementor-countdownpro' ),
      ]
    );


    $repeater = new \Elementor\Repeater();

    $repeater->add_control(
		'img',
		[
			'label' => esc_html__( 'Image', 'elementor-countdownpro' ),
			'type' => \Elementor\Controls_Manager::MEDIA,
			'default' => [
				'url' => \Elementor\Utils::get_placeholder_image_src(),
			]
		]
	  );
    $repeater->add_control(
			'data-link', [
				'label' => __( 'Link For The Image', 'elementor-countdownpro' ),
				'type' => \Elementor\Controls_Manager::TEXT,
        'label_block' => true,
        'default' => '',
			]
		);
    $repeater->add_control(
			'data-target',
			[
				'label' => __( 'Link Target', 'elementor-countdownpro' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => '_blank',
				'options' => [
					'_blank'  => __( 'New Window', 'elementor-countdownpro' ),
					'_self' => __( 'The Same Window', 'elementor-countdownpro' ),
				],
			]
		);
    $repeater->add_control(
      'title', [
        'label' => __( 'Image Title', 'elementor-countdownpro' ),
        'type' => \Elementor\Controls_Manager::TEXT,
        'label_block' => true,
        'default' => '',
      ]
    );


    $this->add_control(
			'list',
			[
				'label' => __( 'Here you can add/edit/delete/clone the social channels', 'elementor-countdownpro' ),
				'type' => \Elementor\Controls_Manager::REPEATER,
				'fields' => $repeater->get_controls(),
        'prevent_empty' => false,
        'default' => [
					[
						'title' => __( 'Social Icon Title', 'elementor-countdownpro' ),
					],
				],
				'title_field' => '{{{ title }}}',
			]
		);


    $this->end_controls_section();
  }

  /**
   * Render the widget output on the frontend.
   *
   * Written in PHP and used to generate the final HTML.
   *
   * @since 1.1.0
   *
   * @access protected
   */
  protected function render() {
    $pathToAjaxFiles_aux=plugin_dir_url(__FILE__).'circular_countdown/';
    $rand_id=rand(10,999999);
    $settings = $this->get_settings_for_display();

    $currentY=date("Y");
    $currentM=date("n");
    $currentD=date("j");
    $currentH=date("H");
    $currentMin=date("i");
    $currentS=date("s");

    $servertime='';
    if ($settings['servertime']=='true') {
  		$servertime=$currentY.','.$currentM.','.$currentD.','.$currentH.','.$currentMin.','.$currentS;
  	}

    $the_logo='';
  	if ($settings['logo']['url']!='') {
  		$the_logo='<div class="logoDiv">'.(($settings['logoLink']!='')?'<a href="'.$settings['logoLink'].'" target="'.$settings['logoTarget'].'">':'').'<img src="'.$settings['logo']['url'].'" alt="logo" border="0" />'.(($settings['logoLink']!='')?'</a>':'').'</div>';
  	}

  	$the_h2='';
  	if ($settings['h2Text']!='') {
  		$the_h2='<h2>'.$settings['h2Text'].'</h2>';
  	}

  	$the_h3='';
  	if ($settings['h3Text']!='') {
  		$the_h3='<h3>'.$settings['h3Text'].'</h3>';
  	}

  	$the_h4='';
  	if ($settings['h4Text']!='') {
  		$the_h4='<h4>'.$settings['h4Text'].'</h4>';
  	}

    //aux hours
  	$aux_divBackgroundHoursImg=$settings["divBackgroundHoursImg"]['url'];
  	$aux_divBackgroundHoursHexa=$settings["divBackgroundHoursHexa"];
  	$aux_borderTopColorHours=$settings["borderTopColorHours"];
  	$aux_borderRightColorHours=$settings["borderRightColorHours"];
  	$aux_borderBottomColorHours=$settings["borderBottomColorHours"];
  	$aux_borderLeftColorHours=$settings["borderLeftColorHours"];
  	$aux_circleColorHours=$settings["circleColorHours"];
  	$aux_behindCircleColorHours=$settings["behindCircleColorHours"];
  	$aux_numberColorHours=$settings["numberColorHours"];
  	$aux_textColorHours=$settings["textColorHours"];
  	$aux_textBackgroundHoursImg=$settings["textBackgroundHoursImg"]['url'];
  	$aux_textBackgroundHoursHexa=$settings["textBackgroundHoursHexa"];

  	//aux minutes
  	$aux_divBackgroundMinutesImg=$settings["divBackgroundMinutesImg"]['url'];
  	$aux_divBackgroundMinutesHexa=$settings["divBackgroundMinutesHexa"];
  	$aux_borderTopColorMinutes=$settings["borderTopColorMinutes"];
  	$aux_borderRightColorMinutes=$settings["borderRightColorMinutes"];
  	$aux_borderBottomColorMinutes=$settings["borderBottomColorMinutes"];
  	$aux_borderLeftColorMinutes=$settings["borderLeftColorMinutes"];
  	$aux_circleColorMinutes=$settings["circleColorMinutes"];
  	$aux_behindCircleColorMinutes=$settings["behindCircleColorMinutes"];
  	$aux_numberColorMinutes=$settings["numberColorMinutes"];
  	$aux_textColorMinutes=$settings["textColorMinutes"];
  	$aux_textBackgroundMinutesImg=$settings["textBackgroundMinutesImg"]['url'];
  	$aux_textBackgroundMinutesHexa=$settings["textBackgroundMinutesHexa"];

  	//aux seconds
  	$aux_divBackgroundSecondsImg=$settings["divBackgroundSecondsImg"]['url'];
  	$aux_divBackgroundSecondsHexa=$settings["divBackgroundSecondsHexa"];
  	$aux_borderTopColorSeconds=$settings["borderTopColorSeconds"];
  	$aux_borderRightColorSeconds=$settings["borderRightColorSeconds"];
  	$aux_borderBottomColorSeconds=$settings["borderBottomColorSeconds"];
  	$aux_borderLeftColorSeconds=$settings["borderLeftColorSeconds"];
  	$aux_circleColorSeconds=$settings["circleColorSeconds"];
  	$aux_behindCircleColorSeconds=$settings["behindCircleColorSeconds"];
  	$aux_numberColorSeconds=$settings["numberColorSeconds"];
  	$aux_textColorSeconds=$settings["textColorSeconds"];
  	$aux_textBackgroundSecondsImg=$settings["textBackgroundSecondsImg"]['url'];
  	$aux_textBackgroundSecondsHexa=$settings["textBackgroundSecondsHexa"];

  	if ($settings["useTheseSettingsForAll"]==='true') {
  				//aux hours
  				$aux_divBackgroundHoursImg=$settings["divBackgroundDaysImg"]['url'];
  				$aux_divBackgroundHoursHexa=$settings["divBackgroundDaysHexa"];
  				$aux_borderTopColorHours=$settings["borderTopColorDays"];
  				$aux_borderRightColorHours=$settings["borderRightColorDays"];
  				$aux_borderBottomColorHours=$settings["borderBottomColorDays"];
  				$aux_borderLeftColorHours=$settings["borderLeftColorDays"];
  				$aux_circleColorHours=$settings["circleColorDays"];
    			$aux_behindCircleColorHours=$settings["behindCircleColorDays"];
  				$aux_numberColorHours=$settings["numberColorDays"];
  				$aux_textColorHours=$settings["textColorDays"];
  				$aux_textBackgroundHoursImg=$settings["textBackgroundDaysImg"]['url'];
  				$aux_textBackgroundHoursHexa=$settings["textBackgroundDaysHexa"];

  				//aux minutes
  				$aux_divBackgroundMinutesImg=$settings["divBackgroundDaysImg"]['url'];
  				$aux_divBackgroundMinutesHexa=$settings["divBackgroundDaysHexa"];
  				$aux_borderTopColorMinutes=$settings["borderTopColorDays"];
  				$aux_borderRightColorMinutes=$settings["borderRightColorDays"];
  				$aux_borderBottomColorMinutes=$settings["borderBottomColorDays"];
  				$aux_borderLeftColorMinutes=$settings["borderLeftColorDays"];
  				$aux_circleColorMinutes=$settings["circleColorDays"];
  				$aux_behindCircleColorMinutes=$settings["behindCircleColorDays"];
  				$aux_numberColorMinutes=$settings["numberColorDays"];
  				$aux_textColorMinutes=$settings["textColorDays"];
  				$aux_textBackgroundMinutesImg=$settings["textBackgroundDaysImg"]['url'];
  				$aux_textBackgroundMinutesHexa=$settings["textBackgroundDaysHexa"];

  				//aux seconds
  				$aux_divBackgroundSecondsImg=$settings["divBackgroundDaysImg"]['url'];
  				$aux_divBackgroundSecondsHexa=$settings["divBackgroundDaysHexa"];
  				$aux_borderTopColorSeconds=$settings["borderTopColorDays"];
  				$aux_borderRightColorSeconds=$settings["borderRightColorDays"];
  				$aux_borderBottomColorSeconds=$settings["borderBottomColorDays"];
  				$aux_borderLeftColorSeconds=$settings["borderLeftColorDays"];
  				$aux_circleColorSeconds=$settings["circleColorDays"];
  				$aux_behindCircleColorSeconds=$settings["behindCircleColorDays"];
  				$aux_numberColorSeconds=$settings["numberColorDays"];
  				$aux_textColorSeconds=$settings["textColorDays"];
  				$aux_textBackgroundSecondsImg=$settings["textBackgroundDaysImg"]['url'];
  				$aux_textBackgroundSecondsHexa=$settings["textBackgroundDaysHexa"];
  	}

    ?>
    <link href="<?php echo esc_js($settings["pluginFontFamilyGoogleLink"]); ?>" rel="stylesheet" type="text/css">
    <script>
  		jQuery(function() {
  			jQuery("#circularCountdown_<?php echo esc_js($rand_id); ?>").circularCountdown({
  				beginDate:"<?php echo esc_js($settings['beginDate']).',00'; ?>",
  				launchingDate:"<?php echo esc_js($settings['launchingDate']).',00'; ?>",
  				nowDate:"<?php echo esc_js($servertime); ?>",
  				responsive:<?php echo (($settings['responsive']==='true')?'true':'false'); ?>,
  				pluginFontFamily:"<?php echo esc_js($settings['pluginFontFamily']); ?>",
  				circleRadius:<?php echo esc_js($settings['circleRadius']); ?>,
  				circleLineWidth:<?php echo esc_js($settings['circleLineWidth']); ?>,
  				behindCircleLineWidthExpand:<?php echo esc_js($settings['behindCircleLineWidthExpand']); ?>,
  				circleTopBottomPadding:<?php echo esc_js($settings['circleTopBottomPadding']); ?>,
  				circleLeftRightPadding:<?php echo esc_js($settings['circleLeftRightPadding']); ?>,
  				numberSize:<?php echo esc_js($settings['numberSize']); ?>,
  				numberAdditionalTopPadding:<?php echo esc_js($settings['numberAdditionalTopPadding']); ?>,
  				textSize:<?php echo esc_js($settings['textSize']); ?>,
  				textMarginTop:<?php echo esc_js($settings['textMarginTop']); ?>,
  				textPadding:<?php echo esc_js($settings['textPadding']); ?>,
  				lineSeparatorImg:"<?php echo esc_js($settings['lineSeparatorImg']['url']); ?>",
  				allCirclesTopMargin:<?php echo esc_js($settings['allCirclesTopMargin']); ?>,
  				allCirclesBottomMargin:<?php echo esc_js($settings['allCirclesBottomMargin']); ?>,
  				socialBgOFF:"<?php echo esc_js($settings['socialBgOFF']['url']); ?>",
  				socialBgON:"<?php echo esc_js($settings['socialBgON']['url']); ?>",
  				complete:<?php echo (($settings["complete"]!='')?$settings["complete"]:'""'); ?>,
  				autoReset24h:<?php echo (($settings['autoReset24h']==='true')?'true':'false'); ?>,

  				divBackgroundDays:"<?php echo (($settings['divBackgroundDaysImg']['url'])?$settings['divBackgroundDaysImg']['url']:$settings['divBackgroundDaysHexa']) ?>",
  				borderTopColorDays:"<?php echo esc_js($settings['borderTopColorDays']); ?>",
  				borderRightColorDays:"<?php echo esc_js($settings['borderRightColorDays']); ?>",
  				borderBottomColorDays:"<?php echo esc_js($settings['borderBottomColorDays']); ?>",
  				borderLeftColorDays:"<?php echo esc_js($settings['borderLeftColorDays']); ?>",
  				circleColorDays:"<?php echo esc_js($settings['circleColorDays']); ?>",
  				behindCircleColorDays:"<?php echo esc_js($settings['behindCircleColorDays']); ?>",
  				numberColorDays:"<?php echo esc_js($settings['numberColorDays']); ?>",
  				textColorDays:"<?php echo esc_js($settings['textColorDays']); ?>",
  				textColorBackgroundDays:"<?php echo (($settings['textBackgroundDaysImg']['url'])?$settings['textBackgroundDaysImg']['url']:$settings['textBackgroundDaysHexa']); ?>",

  				divBackgroundHours:"<?php echo (($aux_divBackgroundHoursImg)?$aux_divBackgroundHoursImg:$aux_divBackgroundHoursHexa); ?>",
  				borderTopColorHours:"<?php echo esc_js($aux_borderTopColorHours); ?>",
  				borderRightColorHours:"<?php echo esc_js($aux_borderRightColorHours); ?>",
  				borderBottomColorHours:"<?php echo esc_js($aux_borderBottomColorHours); ?>",
  				borderLeftColorHours:"<?php echo esc_js($aux_borderLeftColorHours); ?>",
  				circleColorHours:"<?php echo esc_js($aux_circleColorHours); ?>",
  				behindCircleColorHours:"<?php echo esc_js($aux_behindCircleColorHours); ?>",
  				numberColorHours:"<?php echo esc_js($aux_numberColorHours); ?>",
  				textColorHours:"<?php echo esc_js($aux_textColorHours); ?>",
  				textColorBackgroundHours:"<?php echo (($aux_textBackgroundHoursImg)?$aux_textBackgroundHoursImg:$aux_textBackgroundHoursHexa); ?>",

  				divBackgroundMinutes:"<?php echo (($aux_divBackgroundMinutesImg)?$aux_divBackgroundMinutesImg:$aux_divBackgroundMinutesHexa); ?>",
  				borderTopColorMinutes:"<?php echo esc_js($aux_borderTopColorMinutes); ?>",
  				borderRightColorMinutes:"<?php echo esc_js($aux_borderRightColorMinutes); ?>",
  				borderBottomColorMinutes:"<?php echo esc_js($aux_borderBottomColorMinutes); ?>",
  				borderLeftColorMinutes:"<?php echo esc_js($aux_borderLeftColorMinutes); ?>",
  				circleColorMinutes:"<?php echo esc_js($aux_circleColorMinutes); ?>",
  				behindCircleColorMinutes:"<?php echo esc_js($aux_behindCircleColorMinutes); ?>",
  				numberColorMinutes:"<?php echo esc_js($aux_numberColorMinutes); ?>",
  				textColorMinutes:"<?php echo esc_js($aux_textColorMinutes); ?>",
  				textColorBackgroundMinutes:"<?php echo (($aux_textBackgroundMinutesImg)?$aux_textBackgroundMinutesImg:$aux_textBackgroundMinutesHexa); ?>",

  				divBackgroundSeconds:"<?php echo (($aux_divBackgroundSecondsImg)?$aux_divBackgroundSecondsImg:$aux_divBackgroundSecondsHexa); ?>",
  				borderTopColorSeconds:"<?php echo esc_js($aux_borderTopColorSeconds); ?>",
  				borderRightColorSeconds:"<?php echo esc_js($aux_borderRightColorSeconds); ?>",
  				borderBottomColorSeconds:"<?php echo esc_js($aux_borderBottomColorSeconds); ?>",
  				borderLeftColorSeconds:"<?php echo esc_js($aux_borderLeftColorSeconds); ?>",
  				circleColorSeconds:"<?php echo esc_js($aux_circleColorSeconds); ?>",
  				behindCircleColorSeconds:"<?php echo esc_js($aux_behindCircleColorSeconds); ?>",
  				numberColorSeconds:"<?php echo esc_js($aux_numberColorSeconds); ?>",
  				textColorSeconds:"<?php echo esc_js($aux_textColorSeconds); ?>",
  				textColorBackgroundSeconds:"<?php echo (($aux_textBackgroundSecondsImg)?$aux_textBackgroundSecondsImg:$aux_textBackgroundSecondsHexa); ?>",

  				h2Size:<?php echo esc_js($settings['h2Size']); ?>,
  				h2Color:"<?php echo esc_js($settings['h2Color']); ?>",
  				h2Weight:"<?php echo esc_js($settings['h2Weight']); ?>",
  				h2TopMargin:<?php echo esc_js($settings['h2TopMargin']); ?>,

  				h3Size:<?php echo esc_js($settings['h3Size']); ?>,
  				h3Color:"<?php echo esc_js($settings['h3Color']); ?>",
  				h3Weight:"<?php echo esc_js($settings['h3Weight']); ?>",
  				h3TopMargin:<?php echo esc_js($settings['h3TopMargin']); ?>,

  				h4Size:<?php echo esc_js($settings['h4Size']); ?>,
  				h4Color:"<?php echo esc_js($settings['h4Color']); ?>",
  				h4Weight:"<?php echo esc_js($settings['h4Weight']); ?>",
  				h4TopMargin:<?php echo esc_js($settings['h4TopMargin']); ?>

  			});
  		});
  	</script>
      <div id="circularCountdown_<?php echo esc_html($rand_id); ?>"><?php echo strip_tags($the_logo.$the_h2.$the_h3,"<h1><h2><h3><img><a>"); ?>
                  <div class="theCircles xgroup">
                      <div class="daysDiv">
                          <canvas class="canvasDays"></canvas>
                          <div class="innerNumber">0</div>
                          <div class="innerText"><?php echo esc_html($settings['translateDays']);?></div>
                      </div>
                      <div class="hoursDiv">
                          <canvas class="canvasHours"></canvas>
                          <div class="innerNumber">0</div>
                          <div class="innerText"><?php echo esc_html($settings['translateHours']);?></div>
                      </div>
                      <div class="minutesDiv">
                          <canvas class="canvasMinutes"></canvas>
                          <div class="innerNumber">0</div>
                          <div class="innerText"><?php echo esc_html($settings['translateMinutes']);?></div>
                      </div>
                      <div class="secondsDiv">
                          <canvas class="canvasSeconds"></canvas>
                          <div class="innerNumber">0</div>
                          <div class="innerText"><?php echo esc_html($settings['translateSeconds']);?></div>
                      </div>
                  </div>
                  <?php
                  if ( $settings['list'] ) { ?>
                      <div class="socialIconsDiv">
                      <?php echo strip_tags($the_h4,"<h4><a>"); ?>
                      <ul class="socialIcons">
                      <?php foreach (  $settings['list'] as $item ) {
                          echo '<li><a href="'.strip_tags($item['data-link']).'" target="'.strip_tags($item['data-target']).'"><img src="'.strip_tags($item['img']['url']).'" width="auto" height="auto" alt="'.strip_tags($item['title']).'"  title="'.strip_tags($item['title']).'" /></a></li>';
                      } ?>
                      </ul>
                		 </div>
                  <?php }
                  ?>
  	</div>

    <?php
  }

  /**
   * Render the widget output in the editor.
   *
   * Written as a Backbone JavaScript template and used to generate the live preview.
   *
   * @since 1.1.0
   *
   * @access protected
   */
  protected function content_template() {

  }
}
